#ifndef NT2_INCLUDE_FUNCTIONS_PRIMES_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PRIMES_HPP_INCLUDED

#include <nt2/combinatorial/include/functions/primes.hpp>

#endif
